@@ -198,7 +198,7 @@ class BaseScheduler(object):
 
     def check_update_task(self) -> None:
         '''
-        检查更新任务
+        检查更新任务,
         :return:
         '''
         for update_key in self.redis_db.get_update_task():
@@ -293,24 +293,20 @@ class BaseScheduler(object):
                 continue
             process_node_id = all_value["process_node_id"]
             job_id = all_value["job_id"]
-            process_id = int(str(process_node_id).strip().split(':')[-1])
-            job_process_dict[job_id] = process_id
+            job_process_dict[job_id] = process_node_id
         if len(job_process_dict) == 0:
             return job_process_dict
         stores_job_task = self.redis_db.get_stores_job_task()
         for stores_job_key in stores_job_task:
             stores_job_run_times_key = stores_job_key.replace('jobs', 'run_times')
             job_states = self.redis_job_store.redis.hgetall(stores_job_key)
+            stores_job_process_id = stores_job_key.replace('apscheduler:jobs', 'node')
             for job_id, job_state in six.iteritems(job_states):
                 job_id = job_id.decode('utf-8')
                 try:
                     belongs_to_process_id = job_process_dict[job_id]
                 except KeyError:
                     continue
-                try:
-                    stores_job_process_id = int(stores_job_key.split(':')[-1])
-                except ValueError:
-                    continue
                 if stores_job_process_id == belongs_to_process_id:
                     pass
                 else:
@@ -324,6 +320,27 @@ class BaseScheduler(object):
                             pipe.execute()
                     continue
 
+    def check_lost_tasks(self):
+        redis_apscheduler_run_time_job_id_set = set()
+        for apscheduler_run_time_key in self.redis_db.get_stores_job_run_time_task():
+            apscheduler_run_time_byte_list = self.redis_job_store.redis.zrange(
+                apscheduler_run_time_key, 0, 4821384687, withscores=True)
+            for job_states_key_byte, run_time__byte_timestamp in apscheduler_run_time_byte_list:
+                redis_apscheduler_run_time_job_id_set.add(job_states_key_byte.decode())
+
+        for all_key in self.redis_db.get_all_task():
+            all_value = self.redis_db.from_key_get_value(all_key)
+            if all_value is None:
+                continue
+            if all_value.get('job_id') not in redis_apscheduler_run_time_job_id_set:
+                if self.redis_db.acquire(lock_name=all_key):
+                    all_value = self.redis_db.from_key_get_value(all_key)
+                    if all_value is None:
+                        continue
+                    all_value['is_change'] = 1
+                    self.redis_db.string_set(key=all_key, value=json.dumps(all_value, ensure_ascii=False))
+                    self.redis_db.release(lock_name=all_key)
+
     def run(self) -> None:
         '''
         异步检查所有任务
