@@ -17,7 +17,6 @@ class DbRedisHelper(object):
     :param bool ssl: redis 的 ssl
     """
 
-
     def __init__(
             self,
             project_name: str,
@@ -188,3 +187,10 @@ class DbRedisHelper(object):
         :return:
         '''
         return self.connection.keys(pattern=f'{self.project_name}:apscheduler:jobs:*')
+
+    def get_stores_job_run_time_task(self) -> list:
+        '''
+        获取apscheduler存储在redis的所有任务
+        :return:
+        '''
+        return self.connection.keys(pattern=f'{self.project_name}:apscheduler:run_times:*')
