@@ -99,6 +99,10 @@ class TaskScheduler(object):
         def check_redis_jobstores() -> None:
             self.register_base_scheduler.check_redis_jobstores()
 
+        @repeat_every(seconds=10)
+        def check_lost_tasks() -> None:
+            self.register_base_scheduler.check_lost_tasks()
+
         def scheduler_start():
             self.scheduler.start()
 
@@ -108,6 +112,7 @@ class TaskScheduler(object):
         self.app.on_event("startup")(check_process)
         self.app.on_event("startup")(check_scheduler_run)
         self.app.on_event("startup")(check_redis_jobstores)
+        self.app.on_event("startup")(check_lost_tasks)
         self.app.on_event("startup")(scheduler_start)
         self.app.on_event("shutdown")(scheduler_shutdown)
 
